@@ -1,11 +1,8 @@
 use strict; use warnings;
 package
 assign::Test;
+use XXX;
 
-BEGIN {
-    # yath needs this for some reason.
-    $ENV{PERL5LIB} = 'lib';
-}
 use assign::0();
 use Test::More;
 use Capture::Tiny;
